Class: Patch::CreateOrderRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/patch_ruby/models/create_order_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateOrderRequest

Initializes the object



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/patch_ruby/models/create_order_request.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::CreateOrderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::CreateOrderRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'mass_g')
    self.mass_g = attributes[:'mass_g']
  end

  if attributes.key?(:'total_price_cents_usd')
    self.total_price_cents_usd = attributes[:'total_price_cents_usd']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'vintage_year')
    self.vintage_year = attributes[:'vintage_year']
  end

  if attributes.key?(:'total_price')
    self.total_price = attributes[:'total_price']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



34
35
36
# File 'lib/patch_ruby/models/create_order_request.rb', line 34

def amount
  @amount
end

#currencyObject

Returns the value of attribute currency.



32
33
34
# File 'lib/patch_ruby/models/create_order_request.rb', line 32

def currency
  @currency
end

#mass_gObject

Returns the value of attribute mass_g.



18
19
20
# File 'lib/patch_ruby/models/create_order_request.rb', line 18

def mass_g
  @mass_g
end

#metadataObject

Returns the value of attribute metadata.



24
25
26
# File 'lib/patch_ruby/models/create_order_request.rb', line 24

def 
  
end

#project_idObject

Returns the value of attribute project_id.



22
23
24
# File 'lib/patch_ruby/models/create_order_request.rb', line 22

def project_id
  @project_id
end

#stateObject

Returns the value of attribute state.



26
27
28
# File 'lib/patch_ruby/models/create_order_request.rb', line 26

def state
  @state
end

#total_priceObject

Returns the value of attribute total_price.



30
31
32
# File 'lib/patch_ruby/models/create_order_request.rb', line 30

def total_price
  @total_price
end

#total_price_cents_usdObject

Returns the value of attribute total_price_cents_usd.



20
21
22
# File 'lib/patch_ruby/models/create_order_request.rb', line 20

def total_price_cents_usd
  @total_price_cents_usd
end

#unitObject

Returns the value of attribute unit.



36
37
38
# File 'lib/patch_ruby/models/create_order_request.rb', line 36

def unit
  @unit
end

#vintage_yearObject

Returns the value of attribute vintage_year.



28
29
30
# File 'lib/patch_ruby/models/create_order_request.rb', line 28

def vintage_year
  @vintage_year
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/patch_ruby/models/create_order_request.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/patch_ruby/models/create_order_request.rb', line 61

def self.attribute_map
  {
    :'mass_g' => :'mass_g',
    :'total_price_cents_usd' => :'total_price_cents_usd',
    :'project_id' => :'project_id',
    :'metadata' => :'metadata',
    :'state' => :'state',
    :'vintage_year' => :'vintage_year',
    :'total_price' => :'total_price',
    :'currency' => :'currency',
    :'amount' => :'amount',
    :'unit' => :'unit'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



352
353
354
# File 'lib/patch_ruby/models/create_order_request.rb', line 352

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.method_missing(message, *args, &block) ⇒ Object

Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order



117
118
119
120
121
122
123
# File 'lib/patch_ruby/models/create_order_request.rb', line 117

def self.method_missing(message, *args, &block)
  if Object.const_defined?('Patch::CreateOrderRequestsApi::OPERATIONS') && Patch::CreateOrderRequestsApi::OPERATIONS.include?(message)
    Patch::CreateOrderRequestsApi.new.send(message, *args)
  else
    super
  end
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/patch_ruby/models/create_order_request.rb', line 98

def self.openapi_nullable
  Set.new([
    :'mass_g',
    :'total_price_cents_usd',
    :'project_id',
    :'metadata',
    :'state',
    :'vintage_year',
    :'total_price',
    :'currency',
    :'amount',
    :'unit'
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/patch_ruby/models/create_order_request.rb', line 82

def self.openapi_types
  {
    :'mass_g' => :'Integer',
    :'total_price_cents_usd' => :'Integer',
    :'project_id' => :'String',
    :'metadata' => :'Object',
    :'state' => :'String',
    :'vintage_year' => :'Integer',
    :'total_price' => :'Integer',
    :'currency' => :'String',
    :'amount' => :'Integer',
    :'unit' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/patch_ruby/models/create_order_request.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      mass_g == o.mass_g &&
      total_price_cents_usd == o.total_price_cents_usd &&
      project_id == o.project_id &&
       == o. &&
      state == o.state &&
      vintage_year == o.vintage_year &&
      total_price == o.total_price &&
      currency == o.currency &&
      amount == o.amount &&
      unit == o.unit
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/patch_ruby/models/create_order_request.rb', line 382

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Patch.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/patch_ruby/models/create_order_request.rb', line 453

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/patch_ruby/models/create_order_request.rb', line 359

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


339
340
341
# File 'lib/patch_ruby/models/create_order_request.rb', line 339

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



345
346
347
# File 'lib/patch_ruby/models/create_order_request.rb', line 345

def hash
  [mass_g, total_price_cents_usd, project_id, , state, vintage_year, total_price, currency, amount, unit].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/patch_ruby/models/create_order_request.rb', line 183

def list_invalid_properties
  invalid_properties = Array.new
  if !@mass_g.nil? && @mass_g > 100000000000
    invalid_properties.push('invalid value for "mass_g", must be smaller than or equal to 100000000000.')
  end

  if !@mass_g.nil? && @mass_g < 0
    invalid_properties.push('invalid value for "mass_g", must be greater than or equal to 0.')
  end

  if !@total_price_cents_usd.nil? && @total_price_cents_usd < 1
    invalid_properties.push('invalid value for "total_price_cents_usd", must be greater than or equal to 1.')
  end

  if !@vintage_year.nil? && @vintage_year > 2100
    invalid_properties.push('invalid value for "vintage_year", must be smaller than or equal to 2100.')
  end

  if !@vintage_year.nil? && @vintage_year < 1900
    invalid_properties.push('invalid value for "vintage_year", must be greater than or equal to 1900.')
  end

  if !@total_price.nil? && @total_price < 1
    invalid_properties.push('invalid value for "total_price", must be greater than or equal to 1.')
  end

  if !@amount.nil? && @amount > 100000000000
    invalid_properties.push('invalid value for "amount", must be smaller than or equal to 100000000000.')
  end

  if !@amount.nil? && @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



429
430
431
# File 'lib/patch_ruby/models/create_order_request.rb', line 429

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/patch_ruby/models/create_order_request.rb', line 435

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



423
424
425
# File 'lib/patch_ruby/models/create_order_request.rb', line 423

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/patch_ruby/models/create_order_request.rb', line 222

def valid?
  return false if !@mass_g.nil? && @mass_g > 100000000000
  return false if !@mass_g.nil? && @mass_g < 0
  return false if !@total_price_cents_usd.nil? && @total_price_cents_usd < 1
  state_validator = EnumAttributeValidator.new('String', ["draft", "placed"])
  return false unless state_validator.valid?(@state)
  return false if !@vintage_year.nil? && @vintage_year > 2100
  return false if !@vintage_year.nil? && @vintage_year < 1900
  return false if !@total_price.nil? && @total_price < 1
  return false if !@amount.nil? && @amount > 100000000000
  return false if !@amount.nil? && @amount < 0
  unit_validator = EnumAttributeValidator.new('String', ["g", "Wh"])
  return false unless unit_validator.valid?(@unit)
  true
end