Method: Patch::EstimateResponse#initialize
- Defined in:
- lib/patch_ruby/models/estimate_response.rb
#initialize(attributes = {}) ⇒ EstimateResponse
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/patch_ruby/models/estimate_response.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::EstimateResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::EstimateResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'data') self.data = attributes[:'data'] end end |