Class: Patch::Order

Inherits:
Object
  • Object
show all
Defined in:
lib/patch_ruby/models/order.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Order

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/patch_ruby/models/order.rb', line 164

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::Order` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::Order`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'mass_g')
    self.mass_g = attributes[:'mass_g']
  end

  if attributes.key?(:'production')
    self.production = attributes[:'production']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'patch_fee')
    self.patch_fee = attributes[:'patch_fee']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'allocation_state')
    self.allocation_state = attributes[:'allocation_state']
  end

  if attributes.key?(:'price_cents_usd')
    self.price_cents_usd = attributes[:'price_cents_usd']
  end

  if attributes.key?(:'patch_fee_cents_usd')
    self.patch_fee_cents_usd = attributes[:'patch_fee_cents_usd']
  end

  if attributes.key?(:'allocations')
    if (value = attributes[:'allocations']).is_a?(Array)
      self.allocations = value
    end
  end

  if attributes.key?(:'registry_url')
    self.registry_url = attributes[:'registry_url']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'inventory')
    if (value = attributes[:'inventory']).is_a?(Array)
      self.inventory = value
    end
  end
end

Instance Attribute Details

#allocation_stateObject

DEPRECATED. Indicates if the order has been fully allocated to projects.



49
50
51
# File 'lib/patch_ruby/models/order.rb', line 49

def allocation_state
  @allocation_state
end

#allocationsObject

DEPRECATED. An array containing the inventory allocations for this order.



58
59
60
# File 'lib/patch_ruby/models/order.rb', line 58

def allocations
  @allocations
end

#amountObject

The amount in ‘unit`s purchased through this order.



34
35
36
# File 'lib/patch_ruby/models/order.rb', line 34

def amount
  @amount
end

#created_atObject

The timestamp at which the order was created



22
23
24
# File 'lib/patch_ruby/models/order.rb', line 22

def created_at
  @created_at
end

#currencyObject

The currency code for the price and patch_fee.



46
47
48
# File 'lib/patch_ruby/models/order.rb', line 46

def currency
  @currency
end

#idObject

A unique uid for the record. UIDs will be prepended by ord_prod or ord_test depending on the mode it was created in.



19
20
21
# File 'lib/patch_ruby/models/order.rb', line 19

def id
  @id
end

#inventoryObject

An array containing the inventory allocated for this order. Inventory is grouped by project, vintage year, and price.



67
68
69
# File 'lib/patch_ruby/models/order.rb', line 67

def inventory
  @inventory
end

#mass_gObject

DEPRECATED, use amount and unit fields instead. The amount of carbon offsets in grams purchased through this order.



25
26
27
# File 'lib/patch_ruby/models/order.rb', line 25

def mass_g
  @mass_g
end

#metadataObject

An optional JSON object containing metadata for this order.



64
65
66
# File 'lib/patch_ruby/models/order.rb', line 64

def 
  @metadata
end

#patch_feeObject

The Patch Fee for this order. Patch Fee is always represented in the smallest currency unit (ie cents for USD).



43
44
45
# File 'lib/patch_ruby/models/order.rb', line 43

def patch_fee
  @patch_fee
end

#patch_fee_cents_usdObject

DEPRECATED, use the patch_fee and currency fields instead. The Patch Fee in cents USD for this order.



55
56
57
# File 'lib/patch_ruby/models/order.rb', line 55

def patch_fee_cents_usd
  @patch_fee_cents_usd
end

#priceObject

The total price for the amount ordered. Prices are always represented in the smallest currency unit (ie cents for USD).



40
41
42
# File 'lib/patch_ruby/models/order.rb', line 40

def price
  @price
end

#price_cents_usdObject

DEPRECATED, use the price and currency fields instead. The total price in cents USD of the carbon offsets purchased through this order.



52
53
54
# File 'lib/patch_ruby/models/order.rb', line 52

def price_cents_usd
  @price_cents_usd
end

#productionObject

A boolean indicating if this order is a production or test mode order.



28
29
30
# File 'lib/patch_ruby/models/order.rb', line 28

def production
  @production
end

#registry_urlObject

The url of this order in the public registry.



61
62
63
# File 'lib/patch_ruby/models/order.rb', line 61

def registry_url
  @registry_url
end

#stateObject

The current state of the order.



31
32
33
# File 'lib/patch_ruby/models/order.rb', line 31

def state
  @state
end

#unitObject

The unit of measurement (ie "g" or "Wh") for the amount ordered.



37
38
39
# File 'lib/patch_ruby/models/order.rb', line 37

def unit
  @unit
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



115
116
117
# File 'lib/patch_ruby/models/order.rb', line 115

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/patch_ruby/models/order.rb', line 92

def self.attribute_map
  {
    :'id' => :'id',
    :'created_at' => :'created_at',
    :'mass_g' => :'mass_g',
    :'production' => :'production',
    :'state' => :'state',
    :'amount' => :'amount',
    :'unit' => :'unit',
    :'price' => :'price',
    :'patch_fee' => :'patch_fee',
    :'currency' => :'currency',
    :'allocation_state' => :'allocation_state',
    :'price_cents_usd' => :'price_cents_usd',
    :'patch_fee_cents_usd' => :'patch_fee_cents_usd',
    :'allocations' => :'allocations',
    :'registry_url' => :'registry_url',
    :'metadata' => :'metadata',
    :'inventory' => :'inventory'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



437
438
439
# File 'lib/patch_ruby/models/order.rb', line 437

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.method_missing(message, *args, &block) ⇒ Object

Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order



154
155
156
157
158
159
160
# File 'lib/patch_ruby/models/order.rb', line 154

def self.method_missing(message, *args, &block)
  if Object.const_defined?('Patch::OrdersApi::OPERATIONS') && Patch::OrdersApi::OPERATIONS.include?(message)
    Patch::OrdersApi.new.send(message, *args)
  else
    super
  end
end

.openapi_nullableObject

List of attributes with nullable: true



143
144
145
146
147
148
# File 'lib/patch_ruby/models/order.rb', line 143

def self.openapi_nullable
  Set.new([
    :'price_cents_usd',
    :'patch_fee_cents_usd',
  ])
end

.openapi_typesObject

Attribute type mapping.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/patch_ruby/models/order.rb', line 120

def self.openapi_types
  {
    :'id' => :'String',
    :'created_at' => :'Time',
    :'mass_g' => :'Integer',
    :'production' => :'Boolean',
    :'state' => :'String',
    :'amount' => :'Integer',
    :'unit' => :'String',
    :'price' => :'Integer',
    :'patch_fee' => :'Integer',
    :'currency' => :'String',
    :'allocation_state' => :'String',
    :'price_cents_usd' => :'Integer',
    :'patch_fee_cents_usd' => :'Integer',
    :'allocations' => :'Array<Allocation>',
    :'registry_url' => :'String',
    :'metadata' => :'Object',
    :'inventory' => :'Array<OrderInventory>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/patch_ruby/models/order.rb', line 400

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created_at == o.created_at &&
      mass_g == o.mass_g &&
      production == o.production &&
      state == o.state &&
      amount == o.amount &&
      unit == o.unit &&
      price == o.price &&
      patch_fee == o.patch_fee &&
      currency == o.currency &&
      allocation_state == o.allocation_state &&
      price_cents_usd == o.price_cents_usd &&
      patch_fee_cents_usd == o.patch_fee_cents_usd &&
      allocations == o.allocations &&
      registry_url == o.registry_url &&
       == o. &&
      inventory == o.inventory
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/patch_ruby/models/order.rb', line 467

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Patch.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'lib/patch_ruby/models/order.rb', line 538

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/patch_ruby/models/order.rb', line 444

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


424
425
426
# File 'lib/patch_ruby/models/order.rb', line 424

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



430
431
432
# File 'lib/patch_ruby/models/order.rb', line 430

def hash
  [id, created_at, mass_g, production, state, amount, unit, price, patch_fee, currency, allocation_state, price_cents_usd, patch_fee_cents_usd, allocations, registry_url, , inventory].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/patch_ruby/models/order.rb', line 252

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @mass_g.nil?
    invalid_properties.push('invalid value for "mass_g", mass_g cannot be nil.')
  end

  if @mass_g > 100000000000
    invalid_properties.push('invalid value for "mass_g", must be smaller than or equal to 100000000000.')
  end

  if @mass_g < 0
    invalid_properties.push('invalid value for "mass_g", must be greater than or equal to 0.')
  end

  if @production.nil?
    invalid_properties.push('invalid value for "production", production cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount > 100000000000
    invalid_properties.push('invalid value for "amount", must be smaller than or equal to 100000000000.')
  end

  if @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  if @unit.nil?
    invalid_properties.push('invalid value for "unit", unit cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @patch_fee.nil?
    invalid_properties.push('invalid value for "patch_fee", patch_fee cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @allocation_state.nil?
    invalid_properties.push('invalid value for "allocation_state", allocation_state cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



514
515
516
# File 'lib/patch_ruby/models/order.rb', line 514

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/patch_ruby/models/order.rb', line 520

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



508
509
510
# File 'lib/patch_ruby/models/order.rb', line 508

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/patch_ruby/models/order.rb', line 319

def valid?
  return false if @id.nil?
  return false if @mass_g.nil?
  return false if @mass_g > 100000000000
  return false if @mass_g < 0
  return false if @production.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["draft", "placed", "processing", "complete", "cancelled"])
  return false unless state_validator.valid?(@state)
  return false if @amount.nil?
  return false if @amount > 100000000000
  return false if @amount < 0
  return false if @unit.nil?
  return false if @price.nil?
  return false if @patch_fee.nil?
  return false if @currency.nil?
  return false if @allocation_state.nil?
  allocation_state_validator = EnumAttributeValidator.new('String', ["pending", "allocated"])
  return false unless allocation_state_validator.valid?(@allocation_state)
  return false if @metadata.nil?
  true
end