Class: Patch::OrdersApi
- Inherits:
-
Object
- Object
- Patch::OrdersApi
- Defined in:
- lib/patch_ruby/api/orders_api.rb
Constant Summary collapse
- OPERATIONS =
[ :cancel_order, :create_order, :place_order, :retrieve_order, :retrieve_orders, ]
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_order(id, opts = {}) ⇒ OrderResponse
Cancel an order Cancelling an order removes the associated offset allocation from an order.
-
#cancel_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Cancel an order Cancelling an order removes the associated offset allocation from an order.
-
#create_order(create_order_request, opts = {}) ⇒ OrderResponse
Creates an order Creates an order in the
placedstate. -
#create_order_with_http_info(create_order_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Creates an order Creates an order in the `placed` state.
-
#initialize(api_client = ApiClient.default) ⇒ OrdersApi
constructor
A new instance of OrdersApi.
-
#place_order(id, opts = {}) ⇒ OrderResponse
Place an order Placing an order confirms an order’s allocation of offsets.
-
#place_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Place an order Placing an order confirms an order's allocation of offsets.
-
#retrieve_order(id, opts = {}) ⇒ OrderResponse
Retrieves an order Retrieves a given order and its allocation offsets or negative emissions.
-
#retrieve_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Retrieves an order Retrieves a given order and its allocation offsets or negative emissions.
-
#retrieve_orders(opts = {}) ⇒ OrderListResponse
Retrieves a list of orders Retrieves a list of orders and its allocation offsets or negative emissions.
-
#retrieve_orders_with_http_info(opts = {}) ⇒ Array<(OrderListResponse, Integer, Hash)>
Retrieves a list of orders Retrieves a list of orders and its allocation offsets or negative emissions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ OrdersApi
27 28 29 |
# File 'lib/patch_ruby/api/orders_api.rb', line 27 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
25 26 27 |
# File 'lib/patch_ruby/api/orders_api.rb', line 25 def api_client @api_client end |
Instance Method Details
#cancel_order(id, opts = {}) ⇒ OrderResponse
Cancel an order Cancelling an order removes the associated offset allocation from an order. You will not be charged for cancelled orders. Only orders in the draft or placed state can be cancelled.
35 36 37 38 |
# File 'lib/patch_ruby/api/orders_api.rb', line 35 def cancel_order(id, opts = {}) data, _status_code, _headers = cancel_order_with_http_info(id, opts) data end |
#cancel_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Cancel an order Cancelling an order removes the associated offset allocation from an order. You will not be charged for cancelled orders. Only orders in the `draft` or `placed` state can be cancelled.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/patch_ruby/api/orders_api.rb', line 45 def cancel_order_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.cancel_order ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.cancel_order" end # resource path local_var_path = '/v1/orders/{id}/cancel'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'OrderResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#cancel_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_order(create_order_request, opts = {}) ⇒ OrderResponse
Creates an order Creates an order in the placed state. To create a draft order, create an estimate first.
97 98 99 100 |
# File 'lib/patch_ruby/api/orders_api.rb', line 97 def create_order(create_order_request, opts = {}) data, _status_code, _headers = create_order_with_http_info(create_order_request, opts) data end |
#create_order_with_http_info(create_order_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Creates an order Creates an order in the `placed` state. To create a `draft` order, create an estimate first.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/patch_ruby/api/orders_api.rb', line 107 def create_order_with_http_info(create_order_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.create_order ...' end # verify the required parameter 'create_order_request' is set if @api_client.config.client_side_validation && create_order_request.nil? fail ArgumentError, "Missing the required parameter 'create_order_request' when calling OrdersApi.create_order" end # resource path local_var_path = '/v1/orders' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(create_order_request) # return_type return_type = opts[:return_type] || 'OrderResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#create_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#place_order(id, opts = {}) ⇒ OrderResponse
Place an order Placing an order confirms an order’s allocation of offsets. Only orders that are in the draft state can be placed
161 162 163 164 |
# File 'lib/patch_ruby/api/orders_api.rb', line 161 def place_order(id, opts = {}) data, _status_code, _headers = place_order_with_http_info(id, opts) data end |
#place_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Place an order Placing an order confirms an order's allocation of offsets. Only orders that are in the `draft` state can be placed
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/patch_ruby/api/orders_api.rb', line 171 def place_order_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.place_order ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.place_order" end # resource path local_var_path = '/v1/orders/{id}/place'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'OrderResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#place_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retrieve_order(id, opts = {}) ⇒ OrderResponse
Retrieves an order Retrieves a given order and its allocation offsets or negative emissions. You can only retrieve orders associated with the organization you are querying for.
223 224 225 226 |
# File 'lib/patch_ruby/api/orders_api.rb', line 223 def retrieve_order(id, opts = {}) data, _status_code, _headers = retrieve_order_with_http_info(id, opts) data end |
#retrieve_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Retrieves an order Retrieves a given order and its allocation offsets or negative emissions. You can only retrieve orders associated with the organization you are querying for.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/patch_ruby/api/orders_api.rb', line 233 def retrieve_order_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.retrieve_order ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.retrieve_order" end # resource path local_var_path = '/v1/orders/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'OrderResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#retrieve_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retrieve_orders(opts = {}) ⇒ OrderListResponse
Retrieves a list of orders Retrieves a list of orders and its allocation offsets or negative emissions. You can only retrieve orders associated with the organization you are querying for.
285 286 287 288 |
# File 'lib/patch_ruby/api/orders_api.rb', line 285 def retrieve_orders(opts = {}) data, _status_code, _headers = retrieve_orders_with_http_info(opts) data end |
#retrieve_orders_with_http_info(opts = {}) ⇒ Array<(OrderListResponse, Integer, Hash)>
Retrieves a list of orders Retrieves a list of orders and its allocation offsets or negative emissions. You can only retrieve orders associated with the organization you are querying for.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/patch_ruby/api/orders_api.rb', line 295 def retrieve_orders_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.retrieve_orders ...' end # resource path local_var_path = '/v1/orders' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'OrderListResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#retrieve_orders\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |