Class: Patch::Project

Inherits:
Object
  • Object
show all
Defined in:
lib/patch_ruby/models/project.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Project

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/patch_ruby/models/project.rb', line 187

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::Project` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::Project`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'production')
    self.production = attributes[:'production']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'mechanism')
    self.mechanism = attributes[:'mechanism']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'latitude')
    self.latitude = attributes[:'latitude']
  end

  if attributes.key?(:'longitude')
    self.longitude = attributes[:'longitude']
  end

  if attributes.key?(:'developer')
    self.developer = attributes[:'developer']
  end

  if attributes.key?(:'photos')
    if (value = attributes[:'photos']).is_a?(Array)
      self.photos = value
    end
  end

  if attributes.key?(:'average_price_per_tonne_cents_usd')
    self.average_price_per_tonne_cents_usd = attributes[:'average_price_per_tonne_cents_usd']
  end

  if attributes.key?(:'remaining_mass_g')
    self.remaining_mass_g = attributes[:'remaining_mass_g']
  end

  if attributes.key?(:'verifier')
    self.verifier = attributes[:'verifier']
  end

  if attributes.key?(:'standard')
    if (value = attributes[:'standard']).is_a?(Hash)
      self.standard = value
    end
    self.standard = attributes[:'standard']
  end

  if attributes.key?(:'sdgs')
    if (value = attributes[:'sdgs']).is_a?(Array)
      self.sdgs = value
    end
  end

  if attributes.key?(:'tagline')
    self.tagline = attributes[:'tagline']
  end

  if attributes.key?(:'technology_type')
    self.technology_type = attributes[:'technology_type']
  end

  if attributes.key?(:'highlights')
    if (value = attributes[:'highlights']).is_a?(Array)
      self.highlights = value
    end
  end

  if attributes.key?(:'inventory')
    if (value = attributes[:'inventory']).is_a?(Array)
      self.inventory = value
    end
  end
end

Instance Attribute Details

#average_price_per_tonne_cents_usdObject

DEPRECATED. The average price per tonne in USD cents for carbon offsets supplied by this project.



55
56
57
# File 'lib/patch_ruby/models/project.rb', line 55

def average_price_per_tonne_cents_usd
  @average_price_per_tonne_cents_usd
end

#countryObject

The country of origin of the project.



37
38
39
# File 'lib/patch_ruby/models/project.rb', line 37

def country
  @country
end

#descriptionObject

The description of the project.



28
29
30
# File 'lib/patch_ruby/models/project.rb', line 28

def description
  @description
end

#developerObject

The name of the project developer.



49
50
51
# File 'lib/patch_ruby/models/project.rb', line 49

def developer
  @developer
end

#highlightsObject

An array of objects containing the highlight’s slug, title, and a URL for the corresponding icon. A highlight’s title is a short string that spotlights a characteristic about the project.



75
76
77
# File 'lib/patch_ruby/models/project.rb', line 75

def highlights
  @highlights
end

#idObject

A unique uid for the record. UIDs will be prepended by pro_prod or pro_test depending on the mode it was created in.



19
20
21
# File 'lib/patch_ruby/models/project.rb', line 19

def id
  @id
end

#inventoryObject

An array of objects containing available inventory for a project. Available inventory is grouped by a project’s vintage year and returns amount and pricing available for a given vintage year.



78
79
80
# File 'lib/patch_ruby/models/project.rb', line 78

def inventory
  @inventory
end

#latitudeObject

The latitude at which this project is located.



43
44
45
# File 'lib/patch_ruby/models/project.rb', line 43

def latitude
  @latitude
end

#longitudeObject

The longitude at which this project is located.



46
47
48
# File 'lib/patch_ruby/models/project.rb', line 46

def longitude
  @longitude
end

#mechanismObject

The mechanism of the project. Either removal or avoidance.



34
35
36
# File 'lib/patch_ruby/models/project.rb', line 34

def mechanism
  @mechanism
end

#nameObject

The name of the project.



25
26
27
# File 'lib/patch_ruby/models/project.rb', line 25

def name
  @name
end

#photosObject

An array of URLs for photos of the project.



52
53
54
# File 'lib/patch_ruby/models/project.rb', line 52

def photos
  @photos
end

#productionObject

A boolean indicating if this project is a production or test mode project.



22
23
24
# File 'lib/patch_ruby/models/project.rb', line 22

def production
  @production
end

#remaining_mass_gObject

DEPRECATED. The remaining mass in grams available for purchase for this project.



58
59
60
# File 'lib/patch_ruby/models/project.rb', line 58

def remaining_mass_g
  @remaining_mass_g
end

#sdgsObject

An array returning the UN Sustainable Development Goals associated with this project.



67
68
69
# File 'lib/patch_ruby/models/project.rb', line 67

def sdgs
  @sdgs
end

#standardObject

An object returning the Standard associated with this project, when applicable. Standards provide guidance on GHG quantification, monitoring, and reporting. Standards can include protocols/methodologies and guidance documents.



64
65
66
# File 'lib/patch_ruby/models/project.rb', line 64

def standard
  @standard
end

#stateObject

The state where this project is located.



40
41
42
# File 'lib/patch_ruby/models/project.rb', line 40

def state
  @state
end

#taglineObject

A short description of the project.



70
71
72
# File 'lib/patch_ruby/models/project.rb', line 70

def tagline
  @tagline
end

#technology_typeObject

Returns the value of attribute technology_type.



72
73
74
# File 'lib/patch_ruby/models/project.rb', line 72

def technology_type
  @technology_type
end

#typeObject

DEPRECATED. Favor the technology_type field instead.



31
32
33
# File 'lib/patch_ruby/models/project.rb', line 31

def type
  @type
end

#verifierObject

The name of the project verifier, when applicable. A verifier is the organization that verifies the calculations of the actual amount of greenhouse gas emissions that have been avoided or sequestered through implementation of the project.



61
62
63
# File 'lib/patch_ruby/models/project.rb', line 61

def verifier
  @verifier
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



130
131
132
# File 'lib/patch_ruby/models/project.rb', line 130

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/patch_ruby/models/project.rb', line 103

def self.attribute_map
  {
    :'id' => :'id',
    :'production' => :'production',
    :'name' => :'name',
    :'description' => :'description',
    :'type' => :'type',
    :'mechanism' => :'mechanism',
    :'country' => :'country',
    :'state' => :'state',
    :'latitude' => :'latitude',
    :'longitude' => :'longitude',
    :'developer' => :'developer',
    :'photos' => :'photos',
    :'average_price_per_tonne_cents_usd' => :'average_price_per_tonne_cents_usd',
    :'remaining_mass_g' => :'remaining_mass_g',
    :'verifier' => :'verifier',
    :'standard' => :'standard',
    :'sdgs' => :'sdgs',
    :'tagline' => :'tagline',
    :'technology_type' => :'technology_type',
    :'highlights' => :'highlights',
    :'inventory' => :'inventory'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



419
420
421
# File 'lib/patch_ruby/models/project.rb', line 419

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.method_missing(message, *args, &block) ⇒ Object

Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order



177
178
179
180
181
182
183
# File 'lib/patch_ruby/models/project.rb', line 177

def self.method_missing(message, *args, &block)
  if Object.const_defined?('Patch::ProjectsApi::OPERATIONS') && Patch::ProjectsApi::OPERATIONS.include?(message)
    Patch::ProjectsApi.new.send(message, *args)
  else
    super
  end
end

.openapi_nullableObject

List of attributes with nullable: true



162
163
164
165
166
167
168
169
170
171
# File 'lib/patch_ruby/models/project.rb', line 162

def self.openapi_nullable
  Set.new([
    :'state',
    :'latitude',
    :'longitude',
    :'photos',
    :'standard',
    :'sdgs',
  ])
end

.openapi_typesObject

Attribute type mapping.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/patch_ruby/models/project.rb', line 135

def self.openapi_types
  {
    :'id' => :'String',
    :'production' => :'Boolean',
    :'name' => :'String',
    :'description' => :'String',
    :'type' => :'String',
    :'mechanism' => :'String',
    :'country' => :'String',
    :'state' => :'String',
    :'latitude' => :'Float',
    :'longitude' => :'Float',
    :'developer' => :'String',
    :'photos' => :'Array<Photo>',
    :'average_price_per_tonne_cents_usd' => :'Integer',
    :'remaining_mass_g' => :'Integer',
    :'verifier' => :'String',
    :'standard' => :'Standard',
    :'sdgs' => :'Array<Sdg>',
    :'tagline' => :'String',
    :'technology_type' => :'TechnologyType',
    :'highlights' => :'Array<Highlight>',
    :'inventory' => :'Array<Inventory>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/patch_ruby/models/project.rb', line 378

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      production == o.production &&
      name == o.name &&
      description == o.description &&
      type == o.type &&
      mechanism == o.mechanism &&
      country == o.country &&
      state == o.state &&
      latitude == o.latitude &&
      longitude == o.longitude &&
      developer == o.developer &&
      photos == o.photos &&
      average_price_per_tonne_cents_usd == o.average_price_per_tonne_cents_usd &&
      remaining_mass_g == o.remaining_mass_g &&
      verifier == o.verifier &&
      standard == o.standard &&
      sdgs == o.sdgs &&
      tagline == o.tagline &&
      technology_type == o.technology_type &&
      highlights == o.highlights &&
      inventory == o.inventory
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
# File 'lib/patch_ruby/models/project.rb', line 449

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Patch.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/patch_ruby/models/project.rb', line 520

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/patch_ruby/models/project.rb', line 426

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


406
407
408
# File 'lib/patch_ruby/models/project.rb', line 406

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



412
413
414
# File 'lib/patch_ruby/models/project.rb', line 412

def hash
  [id, production, name, description, type, mechanism, country, state, latitude, longitude, developer, photos, average_price_per_tonne_cents_usd, remaining_mass_g, verifier, standard, sdgs, tagline, technology_type, highlights, inventory].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/patch_ruby/models/project.rb', line 298

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @production.nil?
    invalid_properties.push('invalid value for "production", production cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @developer.nil?
    invalid_properties.push('invalid value for "developer", developer cannot be nil.')
  end

  if @average_price_per_tonne_cents_usd.nil?
    invalid_properties.push('invalid value for "average_price_per_tonne_cents_usd", average_price_per_tonne_cents_usd cannot be nil.')
  end

  if @remaining_mass_g.nil?
    invalid_properties.push('invalid value for "remaining_mass_g", remaining_mass_g cannot be nil.')
  end

  if @technology_type.nil?
    invalid_properties.push('invalid value for "technology_type", technology_type cannot be nil.')
  end

  if @highlights.nil?
    invalid_properties.push('invalid value for "highlights", highlights cannot be nil.')
  end

  if @inventory.nil?
    invalid_properties.push('invalid value for "inventory", inventory cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



496
497
498
# File 'lib/patch_ruby/models/project.rb', line 496

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/patch_ruby/models/project.rb', line 502

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



490
491
492
# File 'lib/patch_ruby/models/project.rb', line 490

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/patch_ruby/models/project.rb', line 349

def valid?
  return false if @id.nil?
  return false if @production.nil?
  return false if @name.nil?
  return false if @description.nil?
  mechanism_validator = EnumAttributeValidator.new('String', ["removal", "avoidance"])
  return false unless mechanism_validator.valid?(@mechanism)
  return false if @country.nil?
  return false if @developer.nil?
  return false if @average_price_per_tonne_cents_usd.nil?
  return false if @remaining_mass_g.nil?
  return false if @technology_type.nil?
  return false if @highlights.nil?
  return false if @inventory.nil?
  true
end