Class: Patch::CreateOrderRequest
- Inherits:
-
Object
- Object
- Patch::CreateOrderRequest
- Defined in:
- lib/patch_ruby/models/create_order_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#mass_g ⇒ Object
Returns the value of attribute mass_g.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#state ⇒ Object
Returns the value of attribute state.
-
#total_price_cents_usd ⇒ Object
Returns the value of attribute total_price_cents_usd.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOrderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOrderRequest
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::CreateOrderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::CreateOrderRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'mass_g') self.mass_g = attributes[:'mass_g'] end if attributes.key?(:'total_price_cents_usd') self.total_price_cents_usd = attributes[:'total_price_cents_usd'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'state') self.state = attributes[:'state'] end end |
Instance Attribute Details
#mass_g ⇒ Object
Returns the value of attribute mass_g.
18 19 20 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 18 def mass_g @mass_g end |
#metadata ⇒ Object
Returns the value of attribute metadata.
24 25 26 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 24 def @metadata end |
#project_id ⇒ Object
Returns the value of attribute project_id.
22 23 24 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 22 def project_id @project_id end |
#state ⇒ Object
Returns the value of attribute state.
26 27 28 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 26 def state @state end |
#total_price_cents_usd ⇒ Object
Returns the value of attribute total_price_cents_usd.
20 21 22 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 20 def total_price_cents_usd @total_price_cents_usd end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 62 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 51 def self.attribute_map { :'mass_g' => :'mass_g', :'total_price_cents_usd' => :'total_price_cents_usd', :'project_id' => :'project_id', :'metadata' => :'metadata', :'state' => :'state' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 222 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order
87 88 89 90 91 92 93 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 87 def self.method_missing(, *args, &block) if Object.const_defined?('Patch::CreateOrderRequestsApi::OPERATIONS') && Patch::CreateOrderRequestsApi::OPERATIONS.include?() Patch::CreateOrderRequestsApi.new.send(, *args) else super end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 67 def self.openapi_types { :'mass_g' => :'Integer', :'total_price_cents_usd' => :'Integer', :'project_id' => :'String', :'metadata' => :'Object', :'state' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && mass_g == o.mass_g && total_price_cents_usd == o.total_price_cents_usd && project_id == o.project_id && == o. && state == o.state end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 252 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Patch.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 323 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 229 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
209 210 211 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 209 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 215 def hash [mass_g, total_price_cents_usd, project_id, , state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 133 def list_invalid_properties invalid_properties = Array.new if !@mass_g.nil? && @mass_g > 100000000000 invalid_properties.push('invalid value for "mass_g", must be smaller than or equal to 100000000000.') end if !@mass_g.nil? && @mass_g < 0 invalid_properties.push('invalid value for "mass_g", must be greater than or equal to 0.') end if !@total_price_cents_usd.nil? && @total_price_cents_usd < 1 invalid_properties.push('invalid value for "total_price_cents_usd", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
299 300 301 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 299 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 293 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 152 def valid? return false if !@mass_g.nil? && @mass_g > 100000000000 return false if !@mass_g.nil? && @mass_g < 0 return false if !@total_price_cents_usd.nil? && @total_price_cents_usd < 1 state_validator = EnumAttributeValidator.new('String', ["draft", "placed"]) return false unless state_validator.valid?(@state) true end |