Class: Patch::CreateOrderRequest
- Inherits:
-
Object
- Object
- Patch::CreateOrderRequest
- Defined in:
- lib/patch_ruby/models/create_order_request.rb
Instance Attribute Summary collapse
-
#mass_g ⇒ Object
Returns the value of attribute mass_g.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#total_price_cents_usd ⇒ Object
Returns the value of attribute total_price_cents_usd.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg.
-
.openapi_nullable ⇒ Object
Set with nullable attributes.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOrderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOrderRequest
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::CreateOrderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::CreateOrderRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'mass_g') self.mass_g = attributes[:'mass_g'] end if attributes.key?(:'total_price_cents_usd') self.total_price_cents_usd = attributes[:'total_price_cents_usd'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#mass_g ⇒ Object
Returns the value of attribute mass_g.
17 18 19 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 17 def mass_g @mass_g end |
#metadata ⇒ Object
Returns the value of attribute metadata.
23 24 25 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 23 def @metadata end |
#project_id ⇒ Object
Returns the value of attribute project_id.
21 22 23 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 21 def project_id @project_id end |
#total_price_cents_usd ⇒ Object
Returns the value of attribute total_price_cents_usd.
19 20 21 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 19 def total_price_cents_usd @total_price_cents_usd end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 26 def self.attribute_map { :'mass_g' => :'mass_g', :'total_price_cents_usd' => :'total_price_cents_usd', :'project_id' => :'project_id', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 173 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order
55 56 57 58 59 60 61 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 55 def self.method_missing(, *args, &block) if Object.const_defined?('Patch::CreateOrderRequestsApi::OPERATIONS') && Patch::CreateOrderRequestsApi::OPERATIONS.include?() Patch::CreateOrderRequestsApi.new.send(, *args) else super end end |
.openapi_nullable ⇒ Object
Set with nullable attributes.
46 47 48 49 50 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 46 def self.openapi_nullable nullable_properties = Set.new nullable_properties end |
.openapi_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 36 def self.openapi_types { :'mass_g' => :'Integer', :'total_price_cents_usd' => :'Integer', :'project_id' => :'String', :'metadata' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && mass_g == o.mass_g && total_price_cents_usd == o.total_price_cents_usd && project_id == o.project_id && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 201 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Patch.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 270 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 180 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 166 def hash [mass_g, total_price_cents_usd, project_id, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 97 def list_invalid_properties invalid_properties = Array.new if !@mass_g.nil? && @mass_g > 2000000000 invalid_properties.push('invalid value for "mass_g", must be smaller than or equal to 2000000000.') end if !@mass_g.nil? && @mass_g < 1 invalid_properties.push('invalid value for "mass_g", must be greater than or equal to 1.') end if !@total_price_cents_usd.nil? && @total_price_cents_usd < 1 invalid_properties.push('invalid value for "total_price_cents_usd", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
246 247 248 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 246 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
240 241 242 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 240 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 120 121 |
# File 'lib/patch_ruby/models/create_order_request.rb', line 116 def valid? return false if !@mass_g.nil? && @mass_g > 2000000000 return false if !@mass_g.nil? && @mass_g < 1 return false if !@total_price_cents_usd.nil? && @total_price_cents_usd < 1 true end |