Class: Patch::EstimatesApi
- Inherits:
-
Object
- Object
- Patch::EstimatesApi
- Defined in:
- lib/patch_ruby/api/estimates_api.rb
Constant Summary collapse
- OPERATIONS =
[ :create_bitcoin_estimate, :create_flight_estimate, :create_mass_estimate, :create_shipping_estimate, :create_vehicle_estimate, :retrieve_estimate, :retrieve_estimates, ]
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_bitcoin_estimate(create_bitcoin_estimate_request, opts = {}) ⇒ EstimateResponse
Create a bitcoin estimate given a timestamp and transaction value Creates a bitcoin estimate for the amount of CO2 to be compensated.
-
#create_bitcoin_estimate_with_http_info(create_bitcoin_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a bitcoin estimate given a timestamp and transaction value Creates a bitcoin estimate for the amount of CO2 to be compensated.
-
#create_flight_estimate(create_flight_estimate_request, opts = {}) ⇒ EstimateResponse
Create a flight estimate given the distance traveled in meters Creates a flight estimate for the amount of CO2 to be compensated.
-
#create_flight_estimate_with_http_info(create_flight_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a flight estimate given the distance traveled in meters Creates a flight estimate for the amount of CO2 to be compensated.
-
#create_mass_estimate(create_mass_estimate_request, opts = {}) ⇒ EstimateResponse
Create an estimate based on mass of CO2 Creates an estimate for the mass of CO2 to be compensated.
-
#create_mass_estimate_with_http_info(create_mass_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create an estimate based on mass of CO2 Creates an estimate for the mass of CO2 to be compensated.
-
#create_shipping_estimate(create_shipping_estimate_request, opts = {}) ⇒ EstimateResponse
Create a shipping estimate given the distance traveled in meters, package weight, and transportation method.
-
#create_shipping_estimate_with_http_info(create_shipping_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a shipping estimate given the distance traveled in meters, package weight, and transportation method.
-
#create_vehicle_estimate(create_vehicle_estimate_request, opts = {}) ⇒ EstimateResponse
Create a vehicle estimate given the distance traveled in meters and the type of vehicle Creates an estimate and calculates the amount of CO2 to be compensated depending on the distance and the vehicle.
-
#create_vehicle_estimate_with_http_info(create_vehicle_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a vehicle estimate given the distance traveled in meters and the type of vehicle Creates an estimate and calculates the amount of CO2 to be compensated depending on the distance and the vehicle.
-
#initialize(api_client = ApiClient.default) ⇒ EstimatesApi
constructor
A new instance of EstimatesApi.
-
#retrieve_estimate(id, opts = {}) ⇒ EstimateResponse
Retrieves an estimate Retrieves a given estimate and its associated order.
-
#retrieve_estimate_with_http_info(id, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Retrieves an estimate Retrieves a given estimate and its associated order.
-
#retrieve_estimates(opts = {}) ⇒ EstimateListResponse
Retrieves a list of estimates Retrieves a list of estimates and their associated orders.
-
#retrieve_estimates_with_http_info(opts = {}) ⇒ Array<(EstimateListResponse, Integer, Hash)>
Retrieves a list of estimates Retrieves a list of estimates and their associated orders.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EstimatesApi
Returns a new instance of EstimatesApi.
29 30 31 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 29 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
27 28 29 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 27 def api_client @api_client end |
Instance Method Details
#create_bitcoin_estimate(create_bitcoin_estimate_request, opts = {}) ⇒ EstimateResponse
Create a bitcoin estimate given a timestamp and transaction value Creates a bitcoin estimate for the amount of CO2 to be compensated. An order in the draft state may be created based on the parameters, linked to the estimate.
37 38 39 40 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 37 def create_bitcoin_estimate(create_bitcoin_estimate_request, opts = {}) data, _status_code, _headers = create_bitcoin_estimate_with_http_info(create_bitcoin_estimate_request, opts) data end |
#create_bitcoin_estimate_with_http_info(create_bitcoin_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a bitcoin estimate given a timestamp and transaction value Creates a bitcoin estimate for the amount of CO2 to be compensated. An order in the `draft` state may be created based on the parameters, linked to the estimate.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 47 def create_bitcoin_estimate_with_http_info(create_bitcoin_estimate_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EstimatesApi.create_bitcoin_estimate ...' end # verify the required parameter 'create_bitcoin_estimate_request' is set if @api_client.config.client_side_validation && create_bitcoin_estimate_request.nil? fail ArgumentError, "Missing the required parameter 'create_bitcoin_estimate_request' when calling EstimatesApi.create_bitcoin_estimate" end # resource path local_var_path = '/v1/estimates/crypto/btc' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(create_bitcoin_estimate_request) # return_type return_type = opts[:return_type] || 'EstimateResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EstimatesApi#create_bitcoin_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_flight_estimate(create_flight_estimate_request, opts = {}) ⇒ EstimateResponse
Create a flight estimate given the distance traveled in meters Creates a flight estimate for the amount of CO2 to be compensated. An order in the draft state may be created based on the parameters, linked to the estimate.
101 102 103 104 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 101 def create_flight_estimate(create_flight_estimate_request, opts = {}) data, _status_code, _headers = create_flight_estimate_with_http_info(create_flight_estimate_request, opts) data end |
#create_flight_estimate_with_http_info(create_flight_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a flight estimate given the distance traveled in meters Creates a flight estimate for the amount of CO2 to be compensated. An order in the `draft` state may be created based on the parameters, linked to the estimate.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 111 def create_flight_estimate_with_http_info(create_flight_estimate_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EstimatesApi.create_flight_estimate ...' end # verify the required parameter 'create_flight_estimate_request' is set if @api_client.config.client_side_validation && create_flight_estimate_request.nil? fail ArgumentError, "Missing the required parameter 'create_flight_estimate_request' when calling EstimatesApi.create_flight_estimate" end # resource path local_var_path = '/v1/estimates/flight' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(create_flight_estimate_request) # return_type return_type = opts[:return_type] || 'EstimateResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EstimatesApi#create_flight_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_mass_estimate(create_mass_estimate_request, opts = {}) ⇒ EstimateResponse
Create an estimate based on mass of CO2 Creates an estimate for the mass of CO2 to be compensated. An order in the draft state will also be created, linked to the estimate.
165 166 167 168 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 165 def create_mass_estimate(create_mass_estimate_request, opts = {}) data, _status_code, _headers = create_mass_estimate_with_http_info(create_mass_estimate_request, opts) data end |
#create_mass_estimate_with_http_info(create_mass_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create an estimate based on mass of CO2 Creates an estimate for the mass of CO2 to be compensated. An order in the `draft` state will also be created, linked to the estimate.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 175 def create_mass_estimate_with_http_info(create_mass_estimate_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EstimatesApi.create_mass_estimate ...' end # verify the required parameter 'create_mass_estimate_request' is set if @api_client.config.client_side_validation && create_mass_estimate_request.nil? fail ArgumentError, "Missing the required parameter 'create_mass_estimate_request' when calling EstimatesApi.create_mass_estimate" end # resource path local_var_path = '/v1/estimates/mass' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(create_mass_estimate_request) # return_type return_type = opts[:return_type] || 'EstimateResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EstimatesApi#create_mass_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_shipping_estimate(create_shipping_estimate_request, opts = {}) ⇒ EstimateResponse
Create a shipping estimate given the distance traveled in meters, package weight, and transportation method. Creates a shipping estimate for the amount of CO2 to be compensated. An order in the draft state may be created based on the parameters.
229 230 231 232 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 229 def create_shipping_estimate(create_shipping_estimate_request, opts = {}) data, _status_code, _headers = create_shipping_estimate_with_http_info(create_shipping_estimate_request, opts) data end |
#create_shipping_estimate_with_http_info(create_shipping_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a shipping estimate given the distance traveled in meters, package weight, and transportation method. Creates a shipping estimate for the amount of CO2 to be compensated. An order in the `draft` state may be created based on the parameters.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 239 def create_shipping_estimate_with_http_info(create_shipping_estimate_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EstimatesApi.create_shipping_estimate ...' end # verify the required parameter 'create_shipping_estimate_request' is set if @api_client.config.client_side_validation && create_shipping_estimate_request.nil? fail ArgumentError, "Missing the required parameter 'create_shipping_estimate_request' when calling EstimatesApi.create_shipping_estimate" end # resource path local_var_path = '/v1/estimates/shipping' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(create_shipping_estimate_request) # return_type return_type = opts[:return_type] || 'EstimateResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EstimatesApi#create_shipping_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_vehicle_estimate(create_vehicle_estimate_request, opts = {}) ⇒ EstimateResponse
Create a vehicle estimate given the distance traveled in meters and the type of vehicle Creates an estimate and calculates the amount of CO2 to be compensated depending on the distance and the vehicle. An order in the draft state may be created based on the parameters, linked to the estimate.
293 294 295 296 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 293 def create_vehicle_estimate(create_vehicle_estimate_request, opts = {}) data, _status_code, _headers = create_vehicle_estimate_with_http_info(create_vehicle_estimate_request, opts) data end |
#create_vehicle_estimate_with_http_info(create_vehicle_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Create a vehicle estimate given the distance traveled in meters and the type of vehicle Creates an estimate and calculates the amount of CO2 to be compensated depending on the distance and the vehicle. An order in the `draft` state may be created based on the parameters, linked to the estimate.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 303 def create_vehicle_estimate_with_http_info(create_vehicle_estimate_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EstimatesApi.create_vehicle_estimate ...' end # verify the required parameter 'create_vehicle_estimate_request' is set if @api_client.config.client_side_validation && create_vehicle_estimate_request.nil? fail ArgumentError, "Missing the required parameter 'create_vehicle_estimate_request' when calling EstimatesApi.create_vehicle_estimate" end # resource path local_var_path = '/v1/estimates/vehicle' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(create_vehicle_estimate_request) # return_type return_type = opts[:return_type] || 'EstimateResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EstimatesApi#create_vehicle_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retrieve_estimate(id, opts = {}) ⇒ EstimateResponse
Retrieves an estimate Retrieves a given estimate and its associated order. You can only retrieve estimates associated with the organization you are querying for.
357 358 359 360 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 357 def retrieve_estimate(id, opts = {}) data, _status_code, _headers = retrieve_estimate_with_http_info(id, opts) data end |
#retrieve_estimate_with_http_info(id, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>
Retrieves an estimate Retrieves a given estimate and its associated order. You can only retrieve estimates associated with the organization you are querying for.
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 367 def retrieve_estimate_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EstimatesApi.retrieve_estimate ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EstimatesApi.retrieve_estimate" end # resource path local_var_path = '/v1/estimates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'EstimateResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EstimatesApi#retrieve_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retrieve_estimates(opts = {}) ⇒ EstimateListResponse
Retrieves a list of estimates Retrieves a list of estimates and their associated orders. You can only retrieve estimates associated with the organization you are querying for.
419 420 421 422 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 419 def retrieve_estimates(opts = {}) data, _status_code, _headers = retrieve_estimates_with_http_info(opts) data end |
#retrieve_estimates_with_http_info(opts = {}) ⇒ Array<(EstimateListResponse, Integer, Hash)>
Retrieves a list of estimates Retrieves a list of estimates and their associated orders. You can only retrieve estimates associated with the organization you are querying for.
429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/patch_ruby/api/estimates_api.rb', line 429 def retrieve_estimates_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EstimatesApi.retrieve_estimates ...' end # resource path local_var_path = '/v1/estimates' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'EstimateListResponse' # auth_names auth_names = opts[:auth_names] || ['bearer_auth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EstimatesApi#retrieve_estimates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |