Class: Patch::EstimatesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/patch_ruby/api/estimates_api.rb

Constant Summary collapse

OPERATIONS =
[
  :create_mass_estimate,
  :retrieve_estimate,
  :retrieve_estimates,
]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EstimatesApi

Returns a new instance of EstimatesApi.



25
26
27
# File 'lib/patch_ruby/api/estimates_api.rb', line 25

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



23
24
25
# File 'lib/patch_ruby/api/estimates_api.rb', line 23

def api_client
  @api_client
end

Instance Method Details

#create_mass_estimate(create_mass_estimate_request, opts = {}) ⇒ EstimateResponse

Create an estimate based on mass of CO2 Creates an estimate for the mass of CO2 to be compensated. An order in the draft state will also be created, linked to the estimate.

Parameters:

Returns:



33
34
35
36
# File 'lib/patch_ruby/api/estimates_api.rb', line 33

def create_mass_estimate(create_mass_estimate_request, opts = {})
  data, _status_code, _headers = create_mass_estimate_with_http_info(create_mass_estimate_request, opts)
  data
end

#create_mass_estimate_with_http_info(create_mass_estimate_request, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>

Create an estimate based on mass of CO2 Creates an estimate for the mass of CO2 to be compensated. An order in the &#x60;draft&#x60; state will also be created, linked to the estimate.

Parameters:

Returns:

  • (Array<(EstimateResponse, Integer, Hash)>)

    EstimateResponse data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/patch_ruby/api/estimates_api.rb', line 43

def create_mass_estimate_with_http_info(create_mass_estimate_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EstimatesApi.create_mass_estimate ...'
  end
  # verify the required parameter 'create_mass_estimate_request' is set
  if @api_client.config.client_side_validation && create_mass_estimate_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_mass_estimate_request' when calling EstimatesApi.create_mass_estimate"
  end
  # resource path
  local_var_path = '/v1/estimates/mass'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(create_mass_estimate_request) 

  # return_type
  return_type = opts[:return_type] || 'EstimateResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['bearer_auth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EstimatesApi#create_mass_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retrieve_estimate(id, opts = {}) ⇒ EstimateResponse

Retrieves an estimate Retrieves a given estimate and its associated order. You can only retrieve estimates associated with the organization you are querying for.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



97
98
99
100
# File 'lib/patch_ruby/api/estimates_api.rb', line 97

def retrieve_estimate(id, opts = {})
  data, _status_code, _headers = retrieve_estimate_with_http_info(id, opts)
  data
end

#retrieve_estimate_with_http_info(id, opts = {}) ⇒ Array<(EstimateResponse, Integer, Hash)>

Retrieves an estimate Retrieves a given estimate and its associated order. You can only retrieve estimates associated with the organization you are querying for.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(EstimateResponse, Integer, Hash)>)

    EstimateResponse data, response status code and response headers



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/patch_ruby/api/estimates_api.rb', line 107

def retrieve_estimate_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EstimatesApi.retrieve_estimate ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling EstimatesApi.retrieve_estimate"
  end
  # resource path
  local_var_path = '/v1/estimates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'EstimateResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['bearer_auth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EstimatesApi#retrieve_estimate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retrieve_estimates(opts = {}) ⇒ EstimateListResponse

Retrieves a list of estimates Retrieves a list of estimates and their associated orders. You can only retrieve estimates associated with the organization you are querying for.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

Returns:



159
160
161
162
# File 'lib/patch_ruby/api/estimates_api.rb', line 159

def retrieve_estimates(opts = {})
  data, _status_code, _headers = retrieve_estimates_with_http_info(opts)
  data
end

#retrieve_estimates_with_http_info(opts = {}) ⇒ Array<(EstimateListResponse, Integer, Hash)>

Retrieves a list of estimates Retrieves a list of estimates and their associated orders. You can only retrieve estimates associated with the organization you are querying for.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

Returns:

  • (Array<(EstimateListResponse, Integer, Hash)>)

    EstimateListResponse data, response status code and response headers



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/patch_ruby/api/estimates_api.rb', line 169

def retrieve_estimates_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EstimatesApi.retrieve_estimates ...'
  end
  # resource path
  local_var_path = '/v1/estimates'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'EstimateListResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['bearer_auth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EstimatesApi#retrieve_estimates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end