Class: Patch::Order
- Inherits:
-
Object
- Object
- Patch::Order
- Defined in:
- lib/patch_ruby/models/order.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allocation_state ⇒ Object
The current state of the allocated carbon offsets of the order.
-
#allocations ⇒ Object
An array containing the inventory allocations for this order.
-
#id ⇒ Object
A unique uid for the record.
-
#mass_g ⇒ Object
The amount of carbon offsets in grams purchased through this order.
-
#metadata ⇒ Object
An optional JSON object containing metadata for this order.
-
#patch_fee_cents_usd ⇒ Object
The Patch Fee in cents USD for this order.
-
#price_cents_usd ⇒ Object
The total price in cents USD of the carbon offsets purchased through this order.
-
#production ⇒ Object
A boolean indicating if this order is a production or test mode order.
-
#state ⇒ Object
The current state of the order.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg.
-
.openapi_nullable ⇒ Object
Set with nullable attributes.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Order
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Order
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/patch_ruby/models/order.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::Order` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::Order`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'mass_g') self.mass_g = attributes[:'mass_g'] end if attributes.key?(:'production') self.production = attributes[:'production'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'allocation_state') self.allocation_state = attributes[:'allocation_state'] end if attributes.key?(:'price_cents_usd') self.price_cents_usd = attributes[:'price_cents_usd'] end if attributes.key?(:'patch_fee_cents_usd') self.patch_fee_cents_usd = attributes[:'patch_fee_cents_usd'] end if attributes.key?(:'allocations') if (value = attributes[:'allocations']).is_a?(Array) self.allocations = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#allocation_state ⇒ Object
The current state of the allocated carbon offsets of the order.
30 31 32 |
# File 'lib/patch_ruby/models/order.rb', line 30 def allocation_state @allocation_state end |
#allocations ⇒ Object
An array containing the inventory allocations for this order.
39 40 41 |
# File 'lib/patch_ruby/models/order.rb', line 39 def allocations @allocations end |
#id ⇒ Object
A unique uid for the record. UIDs will be prepended by ord_prod or ord_test depending on the mode it was created in.
18 19 20 |
# File 'lib/patch_ruby/models/order.rb', line 18 def id @id end |
#mass_g ⇒ Object
The amount of carbon offsets in grams purchased through this order.
21 22 23 |
# File 'lib/patch_ruby/models/order.rb', line 21 def mass_g @mass_g end |
#metadata ⇒ Object
An optional JSON object containing metadata for this order.
42 43 44 |
# File 'lib/patch_ruby/models/order.rb', line 42 def @metadata end |
#patch_fee_cents_usd ⇒ Object
The Patch Fee in cents USD for this order.
36 37 38 |
# File 'lib/patch_ruby/models/order.rb', line 36 def patch_fee_cents_usd @patch_fee_cents_usd end |
#price_cents_usd ⇒ Object
The total price in cents USD of the carbon offsets purchased through this order.
33 34 35 |
# File 'lib/patch_ruby/models/order.rb', line 33 def price_cents_usd @price_cents_usd end |
#production ⇒ Object
A boolean indicating if this order is a production or test mode order.
24 25 26 |
# File 'lib/patch_ruby/models/order.rb', line 24 def production @production end |
#state ⇒ Object
The current state of the order.
27 28 29 |
# File 'lib/patch_ruby/models/order.rb', line 27 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/patch_ruby/models/order.rb', line 67 def self.attribute_map { :'id' => :'id', :'mass_g' => :'mass_g', :'production' => :'production', :'state' => :'state', :'allocation_state' => :'allocation_state', :'price_cents_usd' => :'price_cents_usd', :'patch_fee_cents_usd' => :'patch_fee_cents_usd', :'allocations' => :'allocations', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
303 304 305 |
# File 'lib/patch_ruby/models/order.rb', line 303 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order
110 111 112 113 114 115 116 |
# File 'lib/patch_ruby/models/order.rb', line 110 def self.method_missing(, *args, &block) if Object.const_defined?('Patch::OrdersApi::OPERATIONS') && Patch::OrdersApi::OPERATIONS.include?() Patch::OrdersApi.new.send(, *args) else super end end |
.openapi_nullable ⇒ Object
Set with nullable attributes.
97 98 99 100 101 102 103 104 105 |
# File 'lib/patch_ruby/models/order.rb', line 97 def self.openapi_nullable nullable_properties = Set.new nullable_properties.add("price_cents_usd") nullable_properties.add("patch_fee_cents_usd") nullable_properties end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/patch_ruby/models/order.rb', line 82 def self.openapi_types { :'id' => :'String', :'mass_g' => :'Integer', :'production' => :'Boolean', :'state' => :'String', :'allocation_state' => :'String', :'price_cents_usd' => :'String', :'patch_fee_cents_usd' => :'String', :'allocations' => :'Array<Allocation>', :'metadata' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/patch_ruby/models/order.rb', line 274 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && mass_g == o.mass_g && production == o.production && state == o.state && allocation_state == o.allocation_state && price_cents_usd == o.price_cents_usd && patch_fee_cents_usd == o.patch_fee_cents_usd && allocations == o.allocations && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/patch_ruby/models/order.rb', line 331 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Patch.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/patch_ruby/models/order.rb', line 400 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/patch_ruby/models/order.rb', line 310 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
290 291 292 |
# File 'lib/patch_ruby/models/order.rb', line 290 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/patch_ruby/models/order.rb', line 296 def hash [id, mass_g, production, state, allocation_state, price_cents_usd, patch_fee_cents_usd, allocations, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/patch_ruby/models/order.rb', line 174 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @mass_g.nil? invalid_properties.push('invalid value for "mass_g", mass_g cannot be nil.') end if @mass_g > 2000000000 invalid_properties.push('invalid value for "mass_g", must be smaller than or equal to 2000000000.') end if @mass_g < 1 invalid_properties.push('invalid value for "mass_g", must be greater than or equal to 1.') end if @production.nil? invalid_properties.push('invalid value for "production", production cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @allocation_state.nil? invalid_properties.push('invalid value for "allocation_state", allocation_state cannot be nil.') end if @allocations.nil? invalid_properties.push('invalid value for "allocations", allocations cannot be nil.') end if @metadata.nil? invalid_properties.push('invalid value for "metadata", metadata cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
376 377 378 |
# File 'lib/patch_ruby/models/order.rb', line 376 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/patch_ruby/models/order.rb', line 382 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
370 371 372 |
# File 'lib/patch_ruby/models/order.rb', line 370 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/patch_ruby/models/order.rb', line 217 def valid? return false if @id.nil? return false if @mass_g.nil? return false if @mass_g > 2000000000 return false if @mass_g < 1 return false if @production.nil? return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["draft", "placed", "complete", "cancelled"]) return false unless state_validator.valid?(@state) return false if @allocation_state.nil? allocation_state_validator = EnumAttributeValidator.new('String', ["pending", "partially_allocated", "allocated"]) return false unless allocation_state_validator.valid?(@allocation_state) return false if @allocations.nil? return false if @metadata.nil? true end |