Class: Patch::Order

Inherits:
Object
  • Object
show all
Defined in:
lib/patch_ruby/models/order.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Order

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/patch_ruby/models/order.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::Order` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::Order`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'mass_g')
    self.mass_g = attributes[:'mass_g']
  end

  if attributes.key?(:'production')
    self.production = attributes[:'production']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'allocation_state')
    self.allocation_state = attributes[:'allocation_state']
  end

  if attributes.key?(:'price_cents_usd')
    self.price_cents_usd = attributes[:'price_cents_usd']
  end

  if attributes.key?(:'patch_fee_cents_usd')
    self.patch_fee_cents_usd = attributes[:'patch_fee_cents_usd']
  end

  if attributes.key?(:'allocations')
    if (value = attributes[:'allocations']).is_a?(Array)
      self.allocations = value
    end
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#allocation_stateObject

Returns the value of attribute allocation_state.



25
26
27
# File 'lib/patch_ruby/models/order.rb', line 25

def allocation_state
  @allocation_state
end

#allocationsObject

Returns the value of attribute allocations.



31
32
33
# File 'lib/patch_ruby/models/order.rb', line 31

def allocations
  @allocations
end

#idObject

Returns the value of attribute id.



17
18
19
# File 'lib/patch_ruby/models/order.rb', line 17

def id
  @id
end

#mass_gObject

Returns the value of attribute mass_g.



19
20
21
# File 'lib/patch_ruby/models/order.rb', line 19

def mass_g
  @mass_g
end

#metadataObject

Returns the value of attribute metadata.



33
34
35
# File 'lib/patch_ruby/models/order.rb', line 33

def 
  
end

#patch_fee_cents_usdObject

Returns the value of attribute patch_fee_cents_usd.



29
30
31
# File 'lib/patch_ruby/models/order.rb', line 29

def patch_fee_cents_usd
  @patch_fee_cents_usd
end

#price_cents_usdObject

Returns the value of attribute price_cents_usd.



27
28
29
# File 'lib/patch_ruby/models/order.rb', line 27

def price_cents_usd
  @price_cents_usd
end

#productionObject

Returns the value of attribute production.



21
22
23
# File 'lib/patch_ruby/models/order.rb', line 21

def production
  @production
end

#stateObject

Returns the value of attribute state.



23
24
25
# File 'lib/patch_ruby/models/order.rb', line 23

def state
  @state
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/patch_ruby/models/order.rb', line 58

def self.attribute_map
  {
    :'id' => :'id',
    :'mass_g' => :'mass_g',
    :'production' => :'production',
    :'state' => :'state',
    :'allocation_state' => :'allocation_state',
    :'price_cents_usd' => :'price_cents_usd',
    :'patch_fee_cents_usd' => :'patch_fee_cents_usd',
    :'allocations' => :'allocations',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
# File 'lib/patch_ruby/models/order.rb', line 283

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.method_missing(message, *args, &block) ⇒ Object

Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order



90
91
92
93
94
95
96
# File 'lib/patch_ruby/models/order.rb', line 90

def self.method_missing(message, *args, &block)
  if Object.const_defined?('Patch::OrdersApi::OPERATIONS') && Patch::OrdersApi::OPERATIONS.include?(message)
    Patch::OrdersApi.new.send(message, *args)
  else
    super
  end
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/patch_ruby/models/order.rb', line 73

def self.openapi_types
  {
    :'id' => :'String',
    :'mass_g' => :'Integer',
    :'production' => :'Boolean',
    :'state' => :'String',
    :'allocation_state' => :'String',
    :'price_cents_usd' => :'String',
    :'patch_fee_cents_usd' => :'String',
    :'allocations' => :'Array<Allocation>',
    :'metadata' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/patch_ruby/models/order.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      mass_g == o.mass_g &&
      production == o.production &&
      state == o.state &&
      allocation_state == o.allocation_state &&
      price_cents_usd == o.price_cents_usd &&
      patch_fee_cents_usd == o.patch_fee_cents_usd &&
      allocations == o.allocations &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/patch_ruby/models/order.rb', line 311

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Patch.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/patch_ruby/models/order.rb', line 380

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/patch_ruby/models/order.rb', line 290

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/patch_ruby/models/order.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/patch_ruby/models/order.rb', line 276

def hash
  [id, mass_g, production, state, allocation_state, price_cents_usd, patch_fee_cents_usd, allocations, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/patch_ruby/models/order.rb', line 154

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @mass_g.nil?
    invalid_properties.push('invalid value for "mass_g", mass_g cannot be nil.')
  end

  if @mass_g > 2000000000
    invalid_properties.push('invalid value for "mass_g", must be smaller than or equal to 2000000000.')
  end

  if @mass_g < 1
    invalid_properties.push('invalid value for "mass_g", must be greater than or equal to 1.')
  end

  if @production.nil?
    invalid_properties.push('invalid value for "production", production cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @allocation_state.nil?
    invalid_properties.push('invalid value for "allocation_state", allocation_state cannot be nil.')
  end

  if @allocations.nil?
    invalid_properties.push('invalid value for "allocations", allocations cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
# File 'lib/patch_ruby/models/order.rb', line 356

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/patch_ruby/models/order.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



350
351
352
# File 'lib/patch_ruby/models/order.rb', line 350

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/patch_ruby/models/order.rb', line 197

def valid?
  return false if @id.nil?
  return false if @mass_g.nil?
  return false if @mass_g > 2000000000
  return false if @mass_g < 1
  return false if @production.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["draft", "placed", "complete", "cancelled"])
  return false unless state_validator.valid?(@state)
  return false if @allocation_state.nil?
  allocation_state_validator = EnumAttributeValidator.new('String', ["pending", "partially_allocated", "allocated"])
  return false unless allocation_state_validator.valid?(@allocation_state)
  return false if @allocations.nil?
  return false if .nil?
  true
end