Class: Patch::Order
- Inherits:
-
Object
- Object
- Patch::Order
- Defined in:
- lib/patch_ruby/models/order.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allocation_state ⇒ Object
Returns the value of attribute allocation_state.
-
#allocations ⇒ Object
Returns the value of attribute allocations.
-
#id ⇒ Object
Returns the value of attribute id.
-
#mass_g ⇒ Object
Returns the value of attribute mass_g.
-
#price_cents_usd ⇒ Object
Returns the value of attribute price_cents_usd.
-
#production ⇒ Object
Returns the value of attribute production.
-
#state ⇒ Object
Returns the value of attribute state.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Order
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Order
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/patch_ruby/models/order.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::Order` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::Order`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'mass_g') self.mass_g = attributes[:'mass_g'] end if attributes.key?(:'production') self.production = attributes[:'production'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'allocation_state') self.allocation_state = attributes[:'allocation_state'] end if attributes.key?(:'price_cents_usd') self.price_cents_usd = attributes[:'price_cents_usd'] end if attributes.key?(:'allocations') if (value = attributes[:'allocations']).is_a?(Array) self.allocations = value end end end |
Instance Attribute Details
#allocation_state ⇒ Object
Returns the value of attribute allocation_state.
25 26 27 |
# File 'lib/patch_ruby/models/order.rb', line 25 def allocation_state @allocation_state end |
#allocations ⇒ Object
Returns the value of attribute allocations.
29 30 31 |
# File 'lib/patch_ruby/models/order.rb', line 29 def allocations @allocations end |
#id ⇒ Object
Returns the value of attribute id.
17 18 19 |
# File 'lib/patch_ruby/models/order.rb', line 17 def id @id end |
#mass_g ⇒ Object
Returns the value of attribute mass_g.
19 20 21 |
# File 'lib/patch_ruby/models/order.rb', line 19 def mass_g @mass_g end |
#price_cents_usd ⇒ Object
Returns the value of attribute price_cents_usd.
27 28 29 |
# File 'lib/patch_ruby/models/order.rb', line 27 def price_cents_usd @price_cents_usd end |
#production ⇒ Object
Returns the value of attribute production.
21 22 23 |
# File 'lib/patch_ruby/models/order.rb', line 21 def production @production end |
#state ⇒ Object
Returns the value of attribute state.
23 24 25 |
# File 'lib/patch_ruby/models/order.rb', line 23 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/patch_ruby/models/order.rb', line 54 def self.attribute_map { :'id' => :'id', :'mass_g' => :'mass_g', :'production' => :'production', :'state' => :'state', :'allocation_state' => :'allocation_state', :'price_cents_usd' => :'price_cents_usd', :'allocations' => :'allocations' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 |
# File 'lib/patch_ruby/models/order.rb', line 202 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order
82 83 84 85 86 87 88 |
# File 'lib/patch_ruby/models/order.rb', line 82 def self.method_missing(, *args, &block) if Object.const_defined?('Patch::OrdersApi::OPERATIONS') && Patch::OrdersApi::OPERATIONS.include?() Patch::OrdersApi.new.send(, *args) else super end end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/patch_ruby/models/order.rb', line 67 def self.openapi_types { :'id' => :'String', :'mass_g' => :'Integer', :'production' => :'Boolean', :'state' => :'String', :'allocation_state' => :'String', :'price_cents_usd' => :'String', :'allocations' => :'Array<Allocation>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/patch_ruby/models/order.rb', line 175 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && mass_g == o.mass_g && production == o.production && state == o.state && allocation_state == o.allocation_state && price_cents_usd == o.price_cents_usd && allocations == o.allocations end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/patch_ruby/models/order.rb', line 230 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Patch.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/patch_ruby/models/order.rb', line 299 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/patch_ruby/models/order.rb', line 209 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
189 190 191 |
# File 'lib/patch_ruby/models/order.rb', line 189 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/patch_ruby/models/order.rb', line 195 def hash [id, mass_g, production, state, allocation_state, price_cents_usd, allocations].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 |
# File 'lib/patch_ruby/models/order.rb', line 138 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
275 276 277 |
# File 'lib/patch_ruby/models/order.rb', line 275 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/patch_ruby/models/order.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
269 270 271 |
# File 'lib/patch_ruby/models/order.rb', line 269 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 |
# File 'lib/patch_ruby/models/order.rb', line 145 def valid? state_validator = EnumAttributeValidator.new('String', ["draft", "placed", "complete", "cancelled"]) return false unless state_validator.valid?(@state) allocation_state_validator = EnumAttributeValidator.new('String', ["pending", "partially_allocated", "allocated"]) return false unless allocation_state_validator.valid?(@allocation_state) true end |