Class: Patch::Project

Inherits:
Object
  • Object
show all
Defined in:
lib/patch_ruby/models/project.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Project

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/patch_ruby/models/project.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::Project` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::Project`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'production')
    self.production = attributes[:'production']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'developer')
    self.developer = attributes[:'developer']
  end

  if attributes.key?(:'photos')
    if (value = attributes[:'photos']).is_a?(Array)
      self.photos = value
    end
  end

  if attributes.key?(:'average_price_per_tonne_cents_usd')
    self.average_price_per_tonne_cents_usd = attributes[:'average_price_per_tonne_cents_usd']
  end

  if attributes.key?(:'remaining_mass_g')
    self.remaining_mass_g = attributes[:'remaining_mass_g']
  end

  if attributes.key?(:'standard')
    self.standard = attributes[:'standard']
  end
end

Instance Attribute Details

#average_price_per_tonne_cents_usdObject

The average price per tonne in USD cents for carbon offsets supplied by this project.



42
43
44
# File 'lib/patch_ruby/models/project.rb', line 42

def average_price_per_tonne_cents_usd
  @average_price_per_tonne_cents_usd
end

#countryObject

The country of origin of the project.



33
34
35
# File 'lib/patch_ruby/models/project.rb', line 33

def country
  @country
end

#descriptionObject

The description of the project.



27
28
29
# File 'lib/patch_ruby/models/project.rb', line 27

def description
  @description
end

#developerObject

The name of the project developer.



36
37
38
# File 'lib/patch_ruby/models/project.rb', line 36

def developer
  @developer
end

#idObject

A unique uid for the record. UIDs will be prepended by pro_prod or pro_test depending on the mode it was created in.



18
19
20
# File 'lib/patch_ruby/models/project.rb', line 18

def id
  @id
end

#nameObject

The name of the project.



24
25
26
# File 'lib/patch_ruby/models/project.rb', line 24

def name
  @name
end

#photosObject

An array of URLs for photos of the project.



39
40
41
# File 'lib/patch_ruby/models/project.rb', line 39

def photos
  @photos
end

#productionObject

A boolean indicating if this project is a production or test mode project.



21
22
23
# File 'lib/patch_ruby/models/project.rb', line 21

def production
  @production
end

#remaining_mass_gObject

The remaining mass in grams available for purchase for this project.



45
46
47
# File 'lib/patch_ruby/models/project.rb', line 45

def remaining_mass_g
  @remaining_mass_g
end

#standardObject

An object returning the Standard associated with this project.



48
49
50
# File 'lib/patch_ruby/models/project.rb', line 48

def standard
  @standard
end

#typeObject

The type of carbon removal project, currently available project types are Biomass, Dac, Forestry, Mineralization, Ocean, Soil.



30
31
32
# File 'lib/patch_ruby/models/project.rb', line 30

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/patch_ruby/models/project.rb', line 73

def self.attribute_map
  {
    :'id' => :'id',
    :'production' => :'production',
    :'name' => :'name',
    :'description' => :'description',
    :'type' => :'type',
    :'country' => :'country',
    :'developer' => :'developer',
    :'photos' => :'photos',
    :'average_price_per_tonne_cents_usd' => :'average_price_per_tonne_cents_usd',
    :'remaining_mass_g' => :'remaining_mass_g',
    :'standard' => :'standard'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



288
289
290
# File 'lib/patch_ruby/models/project.rb', line 288

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.method_missing(message, *args, &block) ⇒ Object

Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order



120
121
122
123
124
125
126
# File 'lib/patch_ruby/models/project.rb', line 120

def self.method_missing(message, *args, &block)
  if Object.const_defined?('Patch::ProjectsApi::OPERATIONS') && Patch::ProjectsApi::OPERATIONS.include?(message)
    Patch::ProjectsApi.new.send(message, *args)
  else
    super
  end
end

.openapi_nullableObject

Set with nullable attributes.



107
108
109
110
111
112
113
114
115
# File 'lib/patch_ruby/models/project.rb', line 107

def self.openapi_nullable
  nullable_properties = Set.new

  nullable_properties.add("photos")

  nullable_properties.add("standard")

  nullable_properties
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/patch_ruby/models/project.rb', line 90

def self.openapi_types
  {
    :'id' => :'String',
    :'production' => :'Boolean',
    :'name' => :'String',
    :'description' => :'String',
    :'type' => :'String',
    :'country' => :'String',
    :'developer' => :'String',
    :'photos' => :'Array<Photo>',
    :'average_price_per_tonne_cents_usd' => :'Integer',
    :'remaining_mass_g' => :'Integer',
    :'standard' => :'Standard'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/patch_ruby/models/project.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      production == o.production &&
      name == o.name &&
      description == o.description &&
      type == o.type &&
      country == o.country &&
      developer == o.developer &&
      photos == o.photos &&
      average_price_per_tonne_cents_usd == o.average_price_per_tonne_cents_usd &&
      remaining_mass_g == o.remaining_mass_g &&
      standard == o.standard
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/patch_ruby/models/project.rb', line 316

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Patch.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/patch_ruby/models/project.rb', line 385

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/patch_ruby/models/project.rb', line 295

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


275
276
277
# File 'lib/patch_ruby/models/project.rb', line 275

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



281
282
283
# File 'lib/patch_ruby/models/project.rb', line 281

def hash
  [id, production, name, description, type, country, developer, photos, average_price_per_tonne_cents_usd, remaining_mass_g, standard].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/patch_ruby/models/project.rb', line 192

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @production.nil?
    invalid_properties.push('invalid value for "production", production cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @developer.nil?
    invalid_properties.push('invalid value for "developer", developer cannot be nil.')
  end

  if @average_price_per_tonne_cents_usd.nil?
    invalid_properties.push('invalid value for "average_price_per_tonne_cents_usd", average_price_per_tonne_cents_usd cannot be nil.')
  end

  if @remaining_mass_g.nil?
    invalid_properties.push('invalid value for "remaining_mass_g", remaining_mass_g cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
# File 'lib/patch_ruby/models/project.rb', line 361

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/patch_ruby/models/project.rb', line 367

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



355
356
357
# File 'lib/patch_ruby/models/project.rb', line 355

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/patch_ruby/models/project.rb', line 231

def valid?
  return false if @id.nil?
  return false if @production.nil?
  return false if @name.nil?
  return false if @description.nil?
  type_validator = EnumAttributeValidator.new('String', ["biomass", "dac", "forestry", "mineralization", "ocean", "soil"])
  return false unless type_validator.valid?(@type)
  return false if @country.nil?
  return false if @developer.nil?
  return false if @average_price_per_tonne_cents_usd.nil?
  return false if @remaining_mass_g.nil?
  true
end