Class: Patch::UpdateOrderLineItemRequest
- Inherits:
-
Object
- Object
- Patch::UpdateOrderLineItemRequest
- Defined in:
- lib/patch_ruby/models/update_order_line_item_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#price ⇒ Object
Returns the value of attribute price.
-
#unit ⇒ Object
Returns the value of attribute unit.
-
#vintage_year ⇒ Object
Returns the value of attribute vintage_year.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOrderLineItemRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOrderLineItemRequest
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Patch::UpdateOrderLineItemRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Patch::UpdateOrderLineItemRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'vintage_year') self.vintage_year = attributes[:'vintage_year'] end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'unit') self.unit = attributes[:'unit'] end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
24 25 26 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 24 def amount @amount end |
#currency ⇒ Object
Returns the value of attribute currency.
22 23 24 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 22 def currency @currency end |
#price ⇒ Object
Returns the value of attribute price.
20 21 22 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 20 def price @price end |
#unit ⇒ Object
Returns the value of attribute unit.
26 27 28 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 26 def unit @unit end |
#vintage_year ⇒ Object
Returns the value of attribute vintage_year.
18 19 20 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 18 def vintage_year @vintage_year end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 62 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 51 def self.attribute_map { :'vintage_year' => :'vintage_year', :'price' => :'price', :'currency' => :'currency', :'amount' => :'amount', :'unit' => :'unit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 251 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.method_missing(message, *args, &block) ⇒ Object
Allows models with corresponding API classes to delegate API operations to those API classes Exposes Model.operation_id which delegates to ModelsApi.new.operation_id Eg. Order.create_order delegates to OrdersApi.new.create_order
92 93 94 95 96 97 98 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 92 def self.method_missing(, *args, &block) if Object.const_defined?('Patch::UpdateOrderLineItemRequestsApi::OPERATIONS') && Patch::UpdateOrderLineItemRequestsApi::OPERATIONS.include?() Patch::UpdateOrderLineItemRequestsApi.new.send(, *args) else super end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 83 84 85 86 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 78 def self.openapi_nullable Set.new([ :'vintage_year', :'price', :'currency', :'amount', :'unit' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 67 def self.openapi_types { :'vintage_year' => :'Integer', :'price' => :'Integer', :'currency' => :'String', :'amount' => :'Integer', :'unit' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && vintage_year == o.vintage_year && price == o.price && currency == o.currency && amount == o.amount && unit == o.unit end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 281 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Patch.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 352 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 258 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
238 239 240 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 238 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 244 def hash [vintage_year, price, currency, amount, unit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 138 def list_invalid_properties invalid_properties = Array.new if !@vintage_year.nil? && @vintage_year > 2100 invalid_properties.push('invalid value for "vintage_year", must be smaller than or equal to 2100.') end if !@vintage_year.nil? && @vintage_year < 1900 invalid_properties.push('invalid value for "vintage_year", must be greater than or equal to 1900.') end if !@price.nil? && @price < 2 invalid_properties.push('invalid value for "price", must be greater than or equal to 2.') end if !@amount.nil? && @amount > 100000000000 invalid_properties.push('invalid value for "amount", must be smaller than or equal to 100000000000.') end if !@amount.nil? && @amount < 0 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
328 329 330 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 328 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
322 323 324 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 322 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 173 174 |
# File 'lib/patch_ruby/models/update_order_line_item_request.rb', line 165 def valid? return false if !@vintage_year.nil? && @vintage_year > 2100 return false if !@vintage_year.nil? && @vintage_year < 1900 return false if !@price.nil? && @price < 2 return false if !@amount.nil? && @amount > 100000000000 return false if !@amount.nil? && @amount < 0 unit_validator = EnumAttributeValidator.new('String', ["g", "Wh"]) return false unless unit_validator.valid?(@unit) true end |